import { useEffect, useReducer, useState } from 'react';
import { addCustomEventListener, removeCustomEventListener } from '../../../utils/customEventDispatcher';
import { DUMMY_ARRAY } from '../../../utils/constants';
import { DOT_SERVICE_EVENT, DOT_SERVICE_EVENT_TYPE_HIDE_TOAST_NOTIFICATION, DOT_SERVICE_EVENT_TYPE_SHOW_PROMISE_TOAST_NOTIFICATION, DOT_SERVICE_EVENT_TYPE_UPDATE_PROMISE_TOAST_NOTIFICATION, DOT_SERVICE_EVENT_TYPE_HIDE_PROMISE_TOAST_NOTIFICATION, DOT_SERVICE_EVENT_TYPE_SHOW_TOAST_NOTIFICATION } from '../../../service/helpers/constant';
import toastNotificationReducer from '../reducers/toastNotificationReducer';
let toastIdCounter = 0;

const useDOTToastNotificationService = () => {
  const [notifications, dispatch] = useReducer(toastNotificationReducer);

  const handleService = event => {
    if (event.detail.payload.promise) {
      handlePromiseToast({
        dispatch,
        ...event.detail.payload
      });
    } else {
      dispatch(event.detail);
    }
  };

  const handlePromiseToast = _ref => {
    let {
      dispatch,
      promise,
      success,
      error,
      loading
    } = _ref;
    const id = `promiseToast${toastIdCounter++}`;
    const loadingToast = {
      id,
      data: {
        type: 'info',
        ...loading
      }
    };
    dispatch({
      type: DOT_SERVICE_EVENT_TYPE_SHOW_PROMISE_TOAST_NOTIFICATION,
      payload: loadingToast
    });
    promise.then(() => {
      const successToast = {
        id,
        data: {
          type: 'success',
          ...success
        }
      };
      dispatch({
        type: DOT_SERVICE_EVENT_TYPE_UPDATE_PROMISE_TOAST_NOTIFICATION,
        payload: successToast
      }); // setTimeout(() => {
      //     dispatch({
      //         type: DOT_SERVICE_EVENT_TYPE_HIDE_PROMISE_TOAST_NOTIFICATION
      //     })
      // }, 1000);
    }).catch(() => {
      const errorToast = {
        id,
        data: {
          type: 'error',
          ...error
        }
      };
      dispatch({
        type: DOT_SERVICE_EVENT_TYPE_UPDATE_PROMISE_TOAST_NOTIFICATION,
        payload: errorToast
      }); // setTimeout(() => {
      //     dispatch({
      //         type: DOT_SERVICE_EVENT_TYPE_HIDE_PROMISE_TOAST_NOTIFICATION
      //     })
      // }, 1000);
    });
  };

  useEffect(() => {
    addCustomEventListener({
      eventName: DOT_SERVICE_EVENT,
      callback: handleService
    });
    return () => {
      removeCustomEventListener({
        eventName: DOT_SERVICE_EVENT,
        callback: handleService
      });
    };
  }, []);
  return {
    notifications
  };
};

export default useDOTToastNotificationService;